@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the AcousticBrainz API
 
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -80,7 +80,7 @@ WebService::AcousticBrainz - Access to the AcousticBrainz API
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,8 @@ version 0.01
   my $w = WebService::AcousticBrainz->new;
   my $r = $w->fetch(
     mbid     => '96685213-a25c-4678-9a13-abd9ec81cf35',
-    endpoint => 'high-level'
+    endpoint => 'low-level',
+    query    => { n => 2 },
   );
 
 =head1 DESCRIPTION
@@ -120,6 +121,10 @@ B<query> arguments.
 
 L<Moo>
 
+L<use Mojo::UserAgent>
+
+L<use Mojo::JSON::MaybeXS>
+
 L<https://acousticbrainz.org/data>
 
 =head1 AUTHOR
